# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/sqlqueryrun/v1/sqlqueryrun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGgithub.com/metaprov/modelaapi/services/sqlqueryrun/v1/sqlqueryrun.proto\x12\x35github.com.metaprov.modelaapi.services.sqlqueryrun.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xd5\x01\n\x17ListSqlQueryRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12j\n\x06labels\x18\x03 \x03(\x0b\x32Z.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x90\x01\n\x18ListSqlQueryRunsResponse\x12[\n\x0csqlqueryruns\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRunList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x1b\n\x19\x43reateSqlQueryRunResponse\"r\n\x18\x43reateSqlQueryRunRequest\x12V\n\x0bsqlqueryrun\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun\"\xa2\x01\n\x18UpdateSqlQueryRunRequest\x12V\n\x0bsqlqueryrun\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1b\n\x19UpdateSqlQueryRunResponse\"8\n\x15GetSqlQueryRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"~\n\x16GetSqlQueryRunResponse\x12V\n\x0bsqlqueryrun\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\";\n\x18\x44\x65leteSqlQueryRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1b\n\x19\x44\x65leteSqlQueryRunResponse\"o\n\x15RunSqlQueryRunRequest\x12V\n\x0bsqlqueryrun\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.SqlQueryRun\"\x18\n\x16RunSqlQueryRunResponse2\xa8\x0b\n\x12SqlQueryRunService\x12\xda\x01\n\x11ListSqlQuerieRuns\x12N.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest\x1aO.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/sqlqueryruns/{namespace}\x12\xd3\x01\n\x11\x43reateSqlQueryRun\x12O.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.CreateSqlQueryRunRequest\x1aP.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.CreateSqlQueryRunResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/sqlqueryruns:\x01*\x12\xda\x01\n\x0eGetSqlQueryRun\x12L.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunRequest\x1aM.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunResponse\"+\x82\xd3\xe4\x93\x02%\x12#/v1/sqlqueryruns/{namespace}/{name}\x12\x90\x02\n\x11UpdateSqlQueryRun\x12O.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.UpdateSqlQueryRunRequest\x1aP.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.UpdateSqlQueryRunResponse\"X\x82\xd3\xe4\x93\x02R\x1aM/v1/sqlqueryruns/{sqlqueryrun.metadata.namespace}/{sqlqueryrun.metadata.name}:\x01*\x12\xe3\x01\n\x11\x44\x65leteSqlQueryRun\x12O.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunRequest\x1aP.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunResponse\"+\x82\xd3\xe4\x93\x02%*#/v1/sqlqueryruns/{namespace}/{name}\x12\x88\x02\n\x0eRunSqlQueryRun\x12L.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.RunSqlQueryRunRequest\x1aM.github.com.metaprov.modelaapi.services.sqlqueryrun.v1.RunSqlQueryRunResponse\"Y\x82\xd3\xe4\x93\x02S\"Q/v1/sqlqueryruns/{sqlqueryrun.metadata.namespace}/{sqlqueryrun.metadata.name}:runB7Z5github.com/metaprov/modelaapi/services/sqlqueryrun/v1b\x06proto3')



_LISTSQLQUERYRUNSREQUEST = DESCRIPTOR.message_types_by_name['ListSqlQueryRunsRequest']
_LISTSQLQUERYRUNSREQUEST_LABELSENTRY = _LISTSQLQUERYRUNSREQUEST.nested_types_by_name['LabelsEntry']
_LISTSQLQUERYRUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListSqlQueryRunsResponse']
_CREATESQLQUERYRUNRESPONSE = DESCRIPTOR.message_types_by_name['CreateSqlQueryRunResponse']
_CREATESQLQUERYRUNREQUEST = DESCRIPTOR.message_types_by_name['CreateSqlQueryRunRequest']
_UPDATESQLQUERYRUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateSqlQueryRunRequest']
_UPDATESQLQUERYRUNRESPONSE = DESCRIPTOR.message_types_by_name['UpdateSqlQueryRunResponse']
_GETSQLQUERYRUNREQUEST = DESCRIPTOR.message_types_by_name['GetSqlQueryRunRequest']
_GETSQLQUERYRUNRESPONSE = DESCRIPTOR.message_types_by_name['GetSqlQueryRunResponse']
_DELETESQLQUERYRUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteSqlQueryRunRequest']
_DELETESQLQUERYRUNRESPONSE = DESCRIPTOR.message_types_by_name['DeleteSqlQueryRunResponse']
_RUNSQLQUERYRUNREQUEST = DESCRIPTOR.message_types_by_name['RunSqlQueryRunRequest']
_RUNSQLQUERYRUNRESPONSE = DESCRIPTOR.message_types_by_name['RunSqlQueryRunResponse']
ListSqlQueryRunsRequest = _reflection.GeneratedProtocolMessageType('ListSqlQueryRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTSQLQUERYRUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTSQLQUERYRUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsRequest)
  })
_sym_db.RegisterMessage(ListSqlQueryRunsRequest)
_sym_db.RegisterMessage(ListSqlQueryRunsRequest.LabelsEntry)

ListSqlQueryRunsResponse = _reflection.GeneratedProtocolMessageType('ListSqlQueryRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSQLQUERYRUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.ListSqlQueryRunsResponse)
  })
_sym_db.RegisterMessage(ListSqlQueryRunsResponse)

CreateSqlQueryRunResponse = _reflection.GeneratedProtocolMessageType('CreateSqlQueryRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESQLQUERYRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.CreateSqlQueryRunResponse)
  })
_sym_db.RegisterMessage(CreateSqlQueryRunResponse)

CreateSqlQueryRunRequest = _reflection.GeneratedProtocolMessageType('CreateSqlQueryRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESQLQUERYRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.CreateSqlQueryRunRequest)
  })
_sym_db.RegisterMessage(CreateSqlQueryRunRequest)

UpdateSqlQueryRunRequest = _reflection.GeneratedProtocolMessageType('UpdateSqlQueryRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESQLQUERYRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.UpdateSqlQueryRunRequest)
  })
_sym_db.RegisterMessage(UpdateSqlQueryRunRequest)

UpdateSqlQueryRunResponse = _reflection.GeneratedProtocolMessageType('UpdateSqlQueryRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESQLQUERYRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.UpdateSqlQueryRunResponse)
  })
_sym_db.RegisterMessage(UpdateSqlQueryRunResponse)

GetSqlQueryRunRequest = _reflection.GeneratedProtocolMessageType('GetSqlQueryRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSQLQUERYRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunRequest)
  })
_sym_db.RegisterMessage(GetSqlQueryRunRequest)

GetSqlQueryRunResponse = _reflection.GeneratedProtocolMessageType('GetSqlQueryRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSQLQUERYRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.GetSqlQueryRunResponse)
  })
_sym_db.RegisterMessage(GetSqlQueryRunResponse)

DeleteSqlQueryRunRequest = _reflection.GeneratedProtocolMessageType('DeleteSqlQueryRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESQLQUERYRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunRequest)
  })
_sym_db.RegisterMessage(DeleteSqlQueryRunRequest)

DeleteSqlQueryRunResponse = _reflection.GeneratedProtocolMessageType('DeleteSqlQueryRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETESQLQUERYRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.DeleteSqlQueryRunResponse)
  })
_sym_db.RegisterMessage(DeleteSqlQueryRunResponse)

RunSqlQueryRunRequest = _reflection.GeneratedProtocolMessageType('RunSqlQueryRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNSQLQUERYRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.RunSqlQueryRunRequest)
  })
_sym_db.RegisterMessage(RunSqlQueryRunRequest)

RunSqlQueryRunResponse = _reflection.GeneratedProtocolMessageType('RunSqlQueryRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNSQLQUERYRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.sqlqueryrun.v1.sqlqueryrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.sqlqueryrun.v1.RunSqlQueryRunResponse)
  })
_sym_db.RegisterMessage(RunSqlQueryRunResponse)

_SQLQUERYRUNSERVICE = DESCRIPTOR.services_by_name['SqlQueryRunService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/metaprov/modelaapi/services/sqlqueryrun/v1'
  _LISTSQLQUERYRUNSREQUEST_LABELSENTRY._options = None
  _LISTSQLQUERYRUNSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _SQLQUERYRUNSERVICE.methods_by_name['ListSqlQuerieRuns']._options = None
  _SQLQUERYRUNSERVICE.methods_by_name['ListSqlQuerieRuns']._serialized_options = b'\202\323\344\223\002\036\022\034/v1/sqlqueryruns/{namespace}'
  _SQLQUERYRUNSERVICE.methods_by_name['CreateSqlQueryRun']._options = None
  _SQLQUERYRUNSERVICE.methods_by_name['CreateSqlQueryRun']._serialized_options = b'\202\323\344\223\002\025\"\020/v1/sqlqueryruns:\001*'
  _SQLQUERYRUNSERVICE.methods_by_name['GetSqlQueryRun']._options = None
  _SQLQUERYRUNSERVICE.methods_by_name['GetSqlQueryRun']._serialized_options = b'\202\323\344\223\002%\022#/v1/sqlqueryruns/{namespace}/{name}'
  _SQLQUERYRUNSERVICE.methods_by_name['UpdateSqlQueryRun']._options = None
  _SQLQUERYRUNSERVICE.methods_by_name['UpdateSqlQueryRun']._serialized_options = b'\202\323\344\223\002R\032M/v1/sqlqueryruns/{sqlqueryrun.metadata.namespace}/{sqlqueryrun.metadata.name}:\001*'
  _SQLQUERYRUNSERVICE.methods_by_name['DeleteSqlQueryRun']._options = None
  _SQLQUERYRUNSERVICE.methods_by_name['DeleteSqlQueryRun']._serialized_options = b'\202\323\344\223\002%*#/v1/sqlqueryruns/{namespace}/{name}'
  _SQLQUERYRUNSERVICE.methods_by_name['RunSqlQueryRun']._options = None
  _SQLQUERYRUNSERVICE.methods_by_name['RunSqlQueryRun']._serialized_options = b'\202\323\344\223\002S\"Q/v1/sqlqueryruns/{sqlqueryrun.metadata.namespace}/{sqlqueryrun.metadata.name}:run'
  _LISTSQLQUERYRUNSREQUEST._serialized_start=265
  _LISTSQLQUERYRUNSREQUEST._serialized_end=478
  _LISTSQLQUERYRUNSREQUEST_LABELSENTRY._serialized_start=433
  _LISTSQLQUERYRUNSREQUEST_LABELSENTRY._serialized_end=478
  _LISTSQLQUERYRUNSRESPONSE._serialized_start=481
  _LISTSQLQUERYRUNSRESPONSE._serialized_end=625
  _CREATESQLQUERYRUNRESPONSE._serialized_start=627
  _CREATESQLQUERYRUNRESPONSE._serialized_end=654
  _CREATESQLQUERYRUNREQUEST._serialized_start=656
  _CREATESQLQUERYRUNREQUEST._serialized_end=770
  _UPDATESQLQUERYRUNREQUEST._serialized_start=773
  _UPDATESQLQUERYRUNREQUEST._serialized_end=935
  _UPDATESQLQUERYRUNRESPONSE._serialized_start=937
  _UPDATESQLQUERYRUNRESPONSE._serialized_end=964
  _GETSQLQUERYRUNREQUEST._serialized_start=966
  _GETSQLQUERYRUNREQUEST._serialized_end=1022
  _GETSQLQUERYRUNRESPONSE._serialized_start=1024
  _GETSQLQUERYRUNRESPONSE._serialized_end=1150
  _DELETESQLQUERYRUNREQUEST._serialized_start=1152
  _DELETESQLQUERYRUNREQUEST._serialized_end=1211
  _DELETESQLQUERYRUNRESPONSE._serialized_start=1213
  _DELETESQLQUERYRUNRESPONSE._serialized_end=1240
  _RUNSQLQUERYRUNREQUEST._serialized_start=1242
  _RUNSQLQUERYRUNREQUEST._serialized_end=1353
  _RUNSQLQUERYRUNRESPONSE._serialized_start=1355
  _RUNSQLQUERYRUNRESPONSE._serialized_end=1379
  _SQLQUERYRUNSERVICE._serialized_start=1382
  _SQLQUERYRUNSERVICE._serialized_end=2830
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/report/v1/report.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=github.com/metaprov/modelaapi/services/report/v1/report.proto\x12\x30github.com.metaprov.modelaapi.services.report.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\xf1\x01\n\x12ListReportsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12`\n\x06labels\x18\x02 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.report.v1.ListReportsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x85\x01\n\x13ListReportsResponse\x12U\n\x07reports\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ReportList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"g\n\x13\x43reateReportRequest\x12P\n\x06report\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"\x16\n\x14\x43reateReportResponse\"\x97\x01\n\x13UpdateReportRequest\x12P\n\x06report\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x16\n\x14UpdateReportResponse\"3\n\x10GetReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"s\n\x11GetReportResponse\x12P\n\x06report\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"6\n\x13\x44\x65leteReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x16\n\x14\x44\x65leteReportResponse\"8\n\x15\x44ownloadReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"%\n\x16\x44ownloadReportResponse\x12\x0b\n\x03raw\x18\x01 \x01(\x0c\x32\xc8\t\n\rReportService\x12\xbb\x01\n\x0bListReports\x12\x44.github.com.metaprov.modelaapi.services.report.v1.ListReportsRequest\x1a\x45.github.com.metaprov.modelaapi.services.report.v1.ListReportsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/reports/{namespace}\x12\xb5\x01\n\x0c\x43reateReport\x12\x45.github.com.metaprov.modelaapi.services.report.v1.CreateReportRequest\x1a\x46.github.com.metaprov.modelaapi.services.report.v1.CreateReportResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/reports:\x01*\x12\xbc\x01\n\tGetReport\x12\x42.github.com.metaprov.modelaapi.services.report.v1.GetReportRequest\x1a\x43.github.com.metaprov.modelaapi.services.report.v1.GetReportResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/reports/{namespace}/{name}\x12\xe8\x01\n\x0cUpdateReport\x12\x45.github.com.metaprov.modelaapi.services.report.v1.UpdateReportRequest\x1a\x46.github.com.metaprov.modelaapi.services.report.v1.UpdateReportResponse\"I\x82\xd3\xe4\x93\x02\x43\x1a>/v1/reports/{report.metadata.namespace}/{report.metadata.name}:\x01*\x12\xc5\x01\n\x0c\x44\x65leteReport\x12\x45.github.com.metaprov.modelaapi.services.report.v1.DeleteReportRequest\x1a\x46.github.com.metaprov.modelaapi.services.report.v1.DeleteReportResponse\"&\x82\xd3\xe4\x93\x02 *\x1e/v1/reports/{namespace}/{name}\x12\xce\x01\n\x08\x44ownload\x12G.github.com.metaprov.modelaapi.services.report.v1.DownloadReportRequest\x1aH.github.com.metaprov.modelaapi.services.report.v1.DownloadReportResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/v1/reports/{namespace}/{name}:downloadB2Z0github.com/metaprov/modelaapi/services/report/v1b\x06proto3')



_LISTREPORTSREQUEST = DESCRIPTOR.message_types_by_name['ListReportsRequest']
_LISTREPORTSREQUEST_LABELSENTRY = _LISTREPORTSREQUEST.nested_types_by_name['LabelsEntry']
_LISTREPORTSRESPONSE = DESCRIPTOR.message_types_by_name['ListReportsResponse']
_CREATEREPORTREQUEST = DESCRIPTOR.message_types_by_name['CreateReportRequest']
_CREATEREPORTRESPONSE = DESCRIPTOR.message_types_by_name['CreateReportResponse']
_UPDATEREPORTREQUEST = DESCRIPTOR.message_types_by_name['UpdateReportRequest']
_UPDATEREPORTRESPONSE = DESCRIPTOR.message_types_by_name['UpdateReportResponse']
_GETREPORTREQUEST = DESCRIPTOR.message_types_by_name['GetReportRequest']
_GETREPORTRESPONSE = DESCRIPTOR.message_types_by_name['GetReportResponse']
_DELETEREPORTREQUEST = DESCRIPTOR.message_types_by_name['DeleteReportRequest']
_DELETEREPORTRESPONSE = DESCRIPTOR.message_types_by_name['DeleteReportResponse']
_DOWNLOADREPORTREQUEST = DESCRIPTOR.message_types_by_name['DownloadReportRequest']
_DOWNLOADREPORTRESPONSE = DESCRIPTOR.message_types_by_name['DownloadReportResponse']
ListReportsRequest = _reflection.GeneratedProtocolMessageType('ListReportsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTREPORTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.ListReportsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTREPORTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.ListReportsRequest)
  })
_sym_db.RegisterMessage(ListReportsRequest)
_sym_db.RegisterMessage(ListReportsRequest.LabelsEntry)

ListReportsResponse = _reflection.GeneratedProtocolMessageType('ListReportsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTREPORTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.ListReportsResponse)
  })
_sym_db.RegisterMessage(ListReportsResponse)

CreateReportRequest = _reflection.GeneratedProtocolMessageType('CreateReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.CreateReportRequest)
  })
_sym_db.RegisterMessage(CreateReportRequest)

CreateReportResponse = _reflection.GeneratedProtocolMessageType('CreateReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.CreateReportResponse)
  })
_sym_db.RegisterMessage(CreateReportResponse)

UpdateReportRequest = _reflection.GeneratedProtocolMessageType('UpdateReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.UpdateReportRequest)
  })
_sym_db.RegisterMessage(UpdateReportRequest)

UpdateReportResponse = _reflection.GeneratedProtocolMessageType('UpdateReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.UpdateReportResponse)
  })
_sym_db.RegisterMessage(UpdateReportResponse)

GetReportRequest = _reflection.GeneratedProtocolMessageType('GetReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.GetReportRequest)
  })
_sym_db.RegisterMessage(GetReportRequest)

GetReportResponse = _reflection.GeneratedProtocolMessageType('GetReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.GetReportResponse)
  })
_sym_db.RegisterMessage(GetReportResponse)

DeleteReportRequest = _reflection.GeneratedProtocolMessageType('DeleteReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.DeleteReportRequest)
  })
_sym_db.RegisterMessage(DeleteReportRequest)

DeleteReportResponse = _reflection.GeneratedProtocolMessageType('DeleteReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.DeleteReportResponse)
  })
_sym_db.RegisterMessage(DeleteReportResponse)

DownloadReportRequest = _reflection.GeneratedProtocolMessageType('DownloadReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.DownloadReportRequest)
  })
_sym_db.RegisterMessage(DownloadReportRequest)

DownloadReportResponse = _reflection.GeneratedProtocolMessageType('DownloadReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.DownloadReportResponse)
  })
_sym_db.RegisterMessage(DownloadReportResponse)

_REPORTSERVICE = DESCRIPTOR.services_by_name['ReportService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/metaprov/modelaapi/services/report/v1'
  _LISTREPORTSREQUEST_LABELSENTRY._options = None
  _LISTREPORTSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _REPORTSERVICE.methods_by_name['ListReports']._options = None
  _REPORTSERVICE.methods_by_name['ListReports']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/reports/{namespace}'
  _REPORTSERVICE.methods_by_name['CreateReport']._options = None
  _REPORTSERVICE.methods_by_name['CreateReport']._serialized_options = b'\202\323\344\223\002\020\"\013/v1/reports:\001*'
  _REPORTSERVICE.methods_by_name['GetReport']._options = None
  _REPORTSERVICE.methods_by_name['GetReport']._serialized_options = b'\202\323\344\223\002 \022\036/v1/reports/{namespace}/{name}'
  _REPORTSERVICE.methods_by_name['UpdateReport']._options = None
  _REPORTSERVICE.methods_by_name['UpdateReport']._serialized_options = b'\202\323\344\223\002C\032>/v1/reports/{report.metadata.namespace}/{report.metadata.name}:\001*'
  _REPORTSERVICE.methods_by_name['DeleteReport']._options = None
  _REPORTSERVICE.methods_by_name['DeleteReport']._serialized_options = b'\202\323\344\223\002 *\036/v1/reports/{namespace}/{name}'
  _REPORTSERVICE.methods_by_name['Download']._options = None
  _REPORTSERVICE.methods_by_name['Download']._serialized_options = b'\202\323\344\223\002)\022\'/v1/reports/{namespace}/{name}:download'
  _LISTREPORTSREQUEST._serialized_start=254
  _LISTREPORTSREQUEST._serialized_end=495
  _LISTREPORTSREQUEST_LABELSENTRY._serialized_start=450
  _LISTREPORTSREQUEST_LABELSENTRY._serialized_end=495
  _LISTREPORTSRESPONSE._serialized_start=498
  _LISTREPORTSRESPONSE._serialized_end=631
  _CREATEREPORTREQUEST._serialized_start=633
  _CREATEREPORTREQUEST._serialized_end=736
  _CREATEREPORTRESPONSE._serialized_start=738
  _CREATEREPORTRESPONSE._serialized_end=760
  _UPDATEREPORTREQUEST._serialized_start=763
  _UPDATEREPORTREQUEST._serialized_end=914
  _UPDATEREPORTRESPONSE._serialized_start=916
  _UPDATEREPORTRESPONSE._serialized_end=938
  _GETREPORTREQUEST._serialized_start=940
  _GETREPORTREQUEST._serialized_end=991
  _GETREPORTRESPONSE._serialized_start=993
  _GETREPORTRESPONSE._serialized_end=1108
  _DELETEREPORTREQUEST._serialized_start=1110
  _DELETEREPORTREQUEST._serialized_end=1164
  _DELETEREPORTRESPONSE._serialized_start=1166
  _DELETEREPORTRESPONSE._serialized_end=1188
  _DOWNLOADREPORTREQUEST._serialized_start=1190
  _DOWNLOADREPORTREQUEST._serialized_end=1246
  _DOWNLOADREPORTRESPONSE._serialized_start=1248
  _DOWNLOADREPORTRESPONSE._serialized_end=1285
  _REPORTSERVICE._serialized_start=1288
  _REPORTSERVICE._serialized_end=2512
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.onlinefeaturestored.v1 import onlinefeaturestored_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2


class OnlineFeatureStoreServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateFeature = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService/CreateFeature',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.CreateFeatureRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.CreateFeatureResponse.FromString,
                )
        self.DeleteFeature = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService/DeleteFeature',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.DeleteFeatureRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.DeleteFeatureResponse.FromString,
                )
        self.ListFeatures = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService/ListFeatures',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.ListFeaturesRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.ListFeaturesResponse.FromString,
                )
        self.GetFeature = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService/GetFeature',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.GetFeatureRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.GetFeatureResponse.FromString,
                )
        self.UpdateFeature = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService/UpdateFeature',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.UpdateFeatureRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.UpdateFeatureResponse.FromString,
                )
        self.Enrich = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService/Enrich',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.EnrichRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.EnrichResponse.FromString,
                )


class OnlineFeatureStoreServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateFeature(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeature(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListFeatures(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeature(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeature(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Enrich(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OnlineFeatureStoreServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateFeature': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFeature,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.CreateFeatureRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.CreateFeatureResponse.SerializeToString,
            ),
            'DeleteFeature': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeature,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.DeleteFeatureRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.DeleteFeatureResponse.SerializeToString,
            ),
            'ListFeatures': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatures,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.ListFeaturesRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.ListFeaturesResponse.SerializeToString,
            ),
            'GetFeature': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeature,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.GetFeatureRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.GetFeatureResponse.SerializeToString,
            ),
            'UpdateFeature': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeature,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.UpdateFeatureRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.UpdateFeatureResponse.SerializeToString,
            ),
            'Enrich': grpc.unary_unary_rpc_method_handler(
                    servicer.Enrich,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.EnrichRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.EnrichResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OnlineFeatureStoreService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateFeature(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService/CreateFeature',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.CreateFeatureRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.CreateFeatureResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeature(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService/DeleteFeature',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.DeleteFeatureRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.DeleteFeatureResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListFeatures(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService/ListFeatures',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.ListFeaturesRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.ListFeaturesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeature(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService/GetFeature',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.GetFeatureRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.GetFeatureResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeature(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService/UpdateFeature',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.UpdateFeatureRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.UpdateFeatureResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Enrich(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService/Enrich',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.EnrichRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_onlinefeaturestored_dot_v1_dot_onlinefeaturestored__pb2.EnrichResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/commit/v1/commit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=github.com/metaprov/modelaapi/services/commit/v1/commit.proto\x12\x30github.com.metaprov.modelaapi.services.commit.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\x1a google/protobuf/field_mask.proto\"\xf1\x01\n\x12ListCommitsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12`\n\x06labels\x18\x02 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.commit.v1.ListCommitsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"i\n\x13ListCommitsResponse\x12R\n\x07\x63ommits\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.CommitList\"\x10\n\x0e\x43ommitResponse\"v\n\x13\x43reateCommitRequest\x12M\n\x06\x63ommit\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Commit\x12\x10\n\x08password\x18\x02 \x01(\t\"\x16\n\x14\x43reateCommitResponse\"\x94\x01\n\x13UpdateCommitRequest\x12M\n\x06\x63ommit\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Commit\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x16\n\x14UpdateCommitResponse\"3\n\x10GetCommitRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"p\n\x11GetCommitResponse\x12M\n\x06\x63ommit\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Commit\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"=\n\x1aGetCommitNamespacesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"r\n\x1bGetCommitNamespacesResponse\x12S\n\nnamespaces\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo\"6\n\x13\x44\x65leteCommitRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x16\n\x14\x44\x65leteCommitResponse\"\x16\n\x14\x43ommitCreateResponse2\xf7\x07\n\rCommitService\x12\xbb\x01\n\x0bListCommits\x12\x44.github.com.metaprov.modelaapi.services.commit.v1.ListCommitsRequest\x1a\x45.github.com.metaprov.modelaapi.services.commit.v1.ListCommitsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/commits/{namespace}\x12\xb5\x01\n\x0c\x43reateCommit\x12\x45.github.com.metaprov.modelaapi.services.commit.v1.CreateCommitRequest\x1a\x46.github.com.metaprov.modelaapi.services.commit.v1.CreateCommitResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/commits:\x01*\x12\xbc\x01\n\tGetCommit\x12\x42.github.com.metaprov.modelaapi.services.commit.v1.GetCommitRequest\x1a\x43.github.com.metaprov.modelaapi.services.commit.v1.GetCommitResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/commits/{namespace}/{name}\x12\xe8\x01\n\x0cUpdateCommit\x12\x45.github.com.metaprov.modelaapi.services.commit.v1.UpdateCommitRequest\x1a\x46.github.com.metaprov.modelaapi.services.commit.v1.UpdateCommitResponse\"I\x82\xd3\xe4\x93\x02\x43\x1a>/v1/commits/{commit.metadata.namespace}/{commit.metadata.name}:\x01*\x12\xc5\x01\n\x0c\x44\x65leteCommit\x12\x45.github.com.metaprov.modelaapi.services.commit.v1.DeleteCommitRequest\x1a\x46.github.com.metaprov.modelaapi.services.commit.v1.DeleteCommitResponse\"&\x82\xd3\xe4\x93\x02 *\x1e/v1/commits/{namespace}/{name}B2Z0github.com/metaprov/modelaapi/services/commit/v1b\x06proto3')



_LISTCOMMITSREQUEST = DESCRIPTOR.message_types_by_name['ListCommitsRequest']
_LISTCOMMITSREQUEST_LABELSENTRY = _LISTCOMMITSREQUEST.nested_types_by_name['LabelsEntry']
_LISTCOMMITSRESPONSE = DESCRIPTOR.message_types_by_name['ListCommitsResponse']
_COMMITRESPONSE = DESCRIPTOR.message_types_by_name['CommitResponse']
_CREATECOMMITREQUEST = DESCRIPTOR.message_types_by_name['CreateCommitRequest']
_CREATECOMMITRESPONSE = DESCRIPTOR.message_types_by_name['CreateCommitResponse']
_UPDATECOMMITREQUEST = DESCRIPTOR.message_types_by_name['UpdateCommitRequest']
_UPDATECOMMITRESPONSE = DESCRIPTOR.message_types_by_name['UpdateCommitResponse']
_GETCOMMITREQUEST = DESCRIPTOR.message_types_by_name['GetCommitRequest']
_GETCOMMITRESPONSE = DESCRIPTOR.message_types_by_name['GetCommitResponse']
_GETCOMMITNAMESPACESREQUEST = DESCRIPTOR.message_types_by_name['GetCommitNamespacesRequest']
_GETCOMMITNAMESPACESRESPONSE = DESCRIPTOR.message_types_by_name['GetCommitNamespacesResponse']
_DELETECOMMITREQUEST = DESCRIPTOR.message_types_by_name['DeleteCommitRequest']
_DELETECOMMITRESPONSE = DESCRIPTOR.message_types_by_name['DeleteCommitResponse']
_COMMITCREATERESPONSE = DESCRIPTOR.message_types_by_name['CommitCreateResponse']
ListCommitsRequest = _reflection.GeneratedProtocolMessageType('ListCommitsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTCOMMITSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.commit.v1.commit_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.commit.v1.ListCommitsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTCOMMITSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.commit.v1.commit_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.commit.v1.ListCommitsRequest)
  })
_sym_db.RegisterMessage(ListCommitsRequest)
_sym_db.RegisterMessage(ListCommitsRequest.LabelsEntry)

ListCommitsResponse = _reflection.GeneratedProtocolMessageType('ListCommitsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMITSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.commit.v1.commit_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.commit.v1.ListCommitsResponse)
  })
_sym_db.RegisterMessage(ListCommitsResponse)

CommitResponse = _reflection.GeneratedProtocolMessageType('CommitResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMMITRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.commit.v1.commit_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.commit.v1.CommitResponse)
  })
_sym_db.RegisterMessage(CommitResponse)

CreateCommitRequest = _reflection.GeneratedProtocolMessageType('CreateCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOMMITREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.commit.v1.commit_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.commit.v1.CreateCommitRequest)
  })
_sym_db.RegisterMessage(CreateCommitRequest)

CreateCommitResponse = _reflection.GeneratedProtocolMessageType('CreateCommitResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOMMITRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.commit.v1.commit_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.commit.v1.CreateCommitResponse)
  })
_sym_db.RegisterMessage(CreateCommitResponse)

UpdateCommitRequest = _reflection.GeneratedProtocolMessageType('UpdateCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECOMMITREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.commit.v1.commit_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.commit.v1.UpdateCommitRequest)
  })
_sym_db.RegisterMessage(UpdateCommitRequest)

UpdateCommitResponse = _reflection.GeneratedProtocolMessageType('UpdateCommitResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECOMMITRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.commit.v1.commit_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.commit.v1.UpdateCommitResponse)
  })
_sym_db.RegisterMessage(UpdateCommitResponse)

GetCommitRequest = _reflection.GeneratedProtocolMessageType('GetCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMMITREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.commit.v1.commit_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.commit.v1.GetCommitRequest)
  })
_sym_db.RegisterMessage(GetCommitRequest)

GetCommitResponse = _reflection.GeneratedProtocolMessageType('GetCommitResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMMITRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.commit.v1.commit_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.commit.v1.GetCommitResponse)
  })
_sym_db.RegisterMessage(GetCommitResponse)

GetCommitNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetCommitNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMMITNAMESPACESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.commit.v1.commit_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.commit.v1.GetCommitNamespacesRequest)
  })
_sym_db.RegisterMessage(GetCommitNamespacesRequest)

GetCommitNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetCommitNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMMITNAMESPACESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.commit.v1.commit_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.commit.v1.GetCommitNamespacesResponse)
  })
_sym_db.RegisterMessage(GetCommitNamespacesResponse)

DeleteCommitRequest = _reflection.GeneratedProtocolMessageType('DeleteCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECOMMITREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.commit.v1.commit_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.commit.v1.DeleteCommitRequest)
  })
_sym_db.RegisterMessage(DeleteCommitRequest)

DeleteCommitResponse = _reflection.GeneratedProtocolMessageType('DeleteCommitResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECOMMITRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.commit.v1.commit_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.commit.v1.DeleteCommitResponse)
  })
_sym_db.RegisterMessage(DeleteCommitResponse)

CommitCreateResponse = _reflection.GeneratedProtocolMessageType('CommitCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMMITCREATERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.commit.v1.commit_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.commit.v1.CommitCreateResponse)
  })
_sym_db.RegisterMessage(CommitCreateResponse)

_COMMITSERVICE = DESCRIPTOR.services_by_name['CommitService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/metaprov/modelaapi/services/commit/v1'
  _LISTCOMMITSREQUEST_LABELSENTRY._options = None
  _LISTCOMMITSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _COMMITSERVICE.methods_by_name['ListCommits']._options = None
  _COMMITSERVICE.methods_by_name['ListCommits']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/commits/{namespace}'
  _COMMITSERVICE.methods_by_name['CreateCommit']._options = None
  _COMMITSERVICE.methods_by_name['CreateCommit']._serialized_options = b'\202\323\344\223\002\020\"\013/v1/commits:\001*'
  _COMMITSERVICE.methods_by_name['GetCommit']._options = None
  _COMMITSERVICE.methods_by_name['GetCommit']._serialized_options = b'\202\323\344\223\002 \022\036/v1/commits/{namespace}/{name}'
  _COMMITSERVICE.methods_by_name['UpdateCommit']._options = None
  _COMMITSERVICE.methods_by_name['UpdateCommit']._serialized_options = b'\202\323\344\223\002C\032>/v1/commits/{commit.metadata.namespace}/{commit.metadata.name}:\001*'
  _COMMITSERVICE.methods_by_name['DeleteCommit']._options = None
  _COMMITSERVICE.methods_by_name['DeleteCommit']._serialized_options = b'\202\323\344\223\002 *\036/v1/commits/{namespace}/{name}'
  _LISTCOMMITSREQUEST._serialized_start=314
  _LISTCOMMITSREQUEST._serialized_end=555
  _LISTCOMMITSREQUEST_LABELSENTRY._serialized_start=510
  _LISTCOMMITSREQUEST_LABELSENTRY._serialized_end=555
  _LISTCOMMITSRESPONSE._serialized_start=557
  _LISTCOMMITSRESPONSE._serialized_end=662
  _COMMITRESPONSE._serialized_start=664
  _COMMITRESPONSE._serialized_end=680
  _CREATECOMMITREQUEST._serialized_start=682
  _CREATECOMMITREQUEST._serialized_end=800
  _CREATECOMMITRESPONSE._serialized_start=802
  _CREATECOMMITRESPONSE._serialized_end=824
  _UPDATECOMMITREQUEST._serialized_start=827
  _UPDATECOMMITREQUEST._serialized_end=975
  _UPDATECOMMITRESPONSE._serialized_start=977
  _UPDATECOMMITRESPONSE._serialized_end=999
  _GETCOMMITREQUEST._serialized_start=1001
  _GETCOMMITREQUEST._serialized_end=1052
  _GETCOMMITRESPONSE._serialized_start=1054
  _GETCOMMITRESPONSE._serialized_end=1166
  _GETCOMMITNAMESPACESREQUEST._serialized_start=1168
  _GETCOMMITNAMESPACESREQUEST._serialized_end=1229
  _GETCOMMITNAMESPACESRESPONSE._serialized_start=1231
  _GETCOMMITNAMESPACESRESPONSE._serialized_end=1345
  _DELETECOMMITREQUEST._serialized_start=1347
  _DELETECOMMITREQUEST._serialized_end=1401
  _DELETECOMMITRESPONSE._serialized_start=1403
  _DELETECOMMITRESPONSE._serialized_end=1425
  _COMMITCREATERESPONSE._serialized_start=1427
  _COMMITCREATERESPONSE._serialized_end=1449
  _COMMITSERVICE._serialized_start=1452
  _COMMITSERVICE._serialized_end=2467
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: k8s.io/api/apps/v1/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from k8s.io.api.core.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.apis.meta.v1 import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime.schema import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_schema_dot_generated__pb2
from k8s.io.apimachinery.pkg.util.intstr import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_util_dot_intstr_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"k8s.io/api/apps/v1/generated.proto\x12\x12k8s.io.api.apps.v1\x1a\"k8s.io/api/core/v1/generated.proto\x1a\x34k8s.io/apimachinery/pkg/apis/meta/v1/generated.proto\x1a/k8s.io/apimachinery/pkg/runtime/generated.proto\x1a\x36k8s.io/apimachinery/pkg/runtime/schema/generated.proto\x1a\x33k8s.io/apimachinery/pkg/util/intstr/generated.proto\"\xa7\x01\n\x12\x43ontrollerRevision\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.k8s.io.apimachinery.pkg.runtime.RawExtension\x12\x10\n\x08revision\x18\x03 \x01(\x03\"\x91\x01\n\x16\x43ontrollerRevisionList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x35\n\x05items\x18\x02 \x03(\x0b\x32&.k8s.io.api.apps.v1.ControllerRevision\"\xb5\x01\n\tDaemonSet\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12/\n\x04spec\x18\x02 \x01(\x0b\x32!.k8s.io.api.apps.v1.DaemonSetSpec\x12\x33\n\x06status\x18\x03 \x01(\x0b\x32#.k8s.io.api.apps.v1.DaemonSetStatus\"\x9b\x01\n\x12\x44\x61\x65monSetCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x7f\n\rDaemonSetList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.k8s.io.api.apps.v1.DaemonSet\"\x89\x02\n\rDaemonSetSpec\x12\x45\n\x08selector\x18\x01 \x01(\x0b\x32\x33.k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x35\n\x08template\x18\x02 \x01(\x0b\x32#.k8s.io.api.core.v1.PodTemplateSpec\x12\x43\n\x0eupdateStrategy\x18\x03 \x01(\x0b\x32+.k8s.io.api.apps.v1.DaemonSetUpdateStrategy\x12\x17\n\x0fminReadySeconds\x18\x04 \x01(\x05\x12\x1c\n\x14revisionHistoryLimit\x18\x06 \x01(\x05\"\xc6\x02\n\x0f\x44\x61\x65monSetStatus\x12\x1e\n\x16\x63urrentNumberScheduled\x18\x01 \x01(\x05\x12\x1a\n\x12numberMisscheduled\x18\x02 \x01(\x05\x12\x1e\n\x16\x64\x65siredNumberScheduled\x18\x03 \x01(\x05\x12\x13\n\x0bnumberReady\x18\x04 \x01(\x05\x12\x1a\n\x12observedGeneration\x18\x05 \x01(\x03\x12\x1e\n\x16updatedNumberScheduled\x18\x06 \x01(\x05\x12\x17\n\x0fnumberAvailable\x18\x07 \x01(\x05\x12\x19\n\x11numberUnavailable\x18\x08 \x01(\x05\x12\x16\n\x0e\x63ollisionCount\x18\t \x01(\x05\x12:\n\nconditions\x18\n \x03(\x0b\x32&.k8s.io.api.apps.v1.DaemonSetCondition\"j\n\x17\x44\x61\x65monSetUpdateStrategy\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x41\n\rrollingUpdate\x18\x02 \x01(\x0b\x32*.k8s.io.api.apps.v1.RollingUpdateDaemonSet\"\xb8\x01\n\nDeployment\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x30\n\x04spec\x18\x02 \x01(\x0b\x32\".k8s.io.api.apps.v1.DeploymentSpec\x12\x34\n\x06status\x18\x03 \x01(\x0b\x32$.k8s.io.api.apps.v1.DeploymentStatus\"\xe0\x01\n\x13\x44\x65ploymentCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x42\n\x0elastUpdateTime\x18\x06 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x46\n\x12lastTransitionTime\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x81\x01\n\x0e\x44\x65ploymentList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12-\n\x05items\x18\x02 \x03(\x0b\x32\x1e.k8s.io.api.apps.v1.Deployment\"\xc2\x02\n\x0e\x44\x65ploymentSpec\x12\x10\n\x08replicas\x18\x01 \x01(\x05\x12\x45\n\x08selector\x18\x02 \x01(\x0b\x32\x33.k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x35\n\x08template\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.PodTemplateSpec\x12\x38\n\x08strategy\x18\x04 \x01(\x0b\x32&.k8s.io.api.apps.v1.DeploymentStrategy\x12\x17\n\x0fminReadySeconds\x18\x05 \x01(\x05\x12\x1c\n\x14revisionHistoryLimit\x18\x06 \x01(\x05\x12\x0e\n\x06paused\x18\x07 \x01(\x08\x12\x1f\n\x17progressDeadlineSeconds\x18\t \x01(\x05\"\xfd\x01\n\x10\x44\x65ploymentStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12\x10\n\x08replicas\x18\x02 \x01(\x05\x12\x17\n\x0fupdatedReplicas\x18\x03 \x01(\x05\x12\x15\n\rreadyReplicas\x18\x07 \x01(\x05\x12\x19\n\x11\x61vailableReplicas\x18\x04 \x01(\x05\x12\x1b\n\x13unavailableReplicas\x18\x05 \x01(\x05\x12;\n\nconditions\x18\x06 \x03(\x0b\x32\'.k8s.io.api.apps.v1.DeploymentCondition\x12\x16\n\x0e\x63ollisionCount\x18\x08 \x01(\x05\"f\n\x12\x44\x65ploymentStrategy\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x42\n\rrollingUpdate\x18\x02 \x01(\x0b\x32+.k8s.io.api.apps.v1.RollingUpdateDeployment\"\xb8\x01\n\nReplicaSet\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x30\n\x04spec\x18\x02 \x01(\x0b\x32\".k8s.io.api.apps.v1.ReplicaSetSpec\x12\x34\n\x06status\x18\x03 \x01(\x0b\x32$.k8s.io.api.apps.v1.ReplicaSetStatus\"\x9c\x01\n\x13ReplicaSetCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x81\x01\n\x0eReplicaSetList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12-\n\x05items\x18\x02 \x03(\x0b\x32\x1e.k8s.io.api.apps.v1.ReplicaSet\"\xb9\x01\n\x0eReplicaSetSpec\x12\x10\n\x08replicas\x18\x01 \x01(\x05\x12\x17\n\x0fminReadySeconds\x18\x04 \x01(\x05\x12\x45\n\x08selector\x18\x02 \x01(\x0b\x32\x33.k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x35\n\x08template\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.PodTemplateSpec\"\xcd\x01\n\x10ReplicaSetStatus\x12\x10\n\x08replicas\x18\x01 \x01(\x05\x12\x1c\n\x14\x66ullyLabeledReplicas\x18\x02 \x01(\x05\x12\x15\n\rreadyReplicas\x18\x04 \x01(\x05\x12\x19\n\x11\x61vailableReplicas\x18\x05 \x01(\x05\x12\x1a\n\x12observedGeneration\x18\x03 \x01(\x03\x12;\n\nconditions\x18\x06 \x03(\x0b\x32\'.k8s.io.api.apps.v1.ReplicaSetCondition\"\xa6\x01\n\x16RollingUpdateDaemonSet\x12H\n\x0emaxUnavailable\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.util.intstr.IntOrString\x12\x42\n\x08maxSurge\x18\x02 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.util.intstr.IntOrString\"\xa7\x01\n\x17RollingUpdateDeployment\x12H\n\x0emaxUnavailable\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.util.intstr.IntOrString\x12\x42\n\x08maxSurge\x18\x02 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.util.intstr.IntOrString\"\x7f\n RollingUpdateStatefulSetStrategy\x12\x11\n\tpartition\x18\x01 \x01(\x05\x12H\n\x0emaxUnavailable\x18\x02 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.util.intstr.IntOrString\"\xbb\x01\n\x0bStatefulSet\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x31\n\x04spec\x18\x02 \x01(\x0b\x32#.k8s.io.api.apps.v1.StatefulSetSpec\x12\x35\n\x06status\x18\x03 \x01(\x0b\x32%.k8s.io.api.apps.v1.StatefulSetStatus\"\x9d\x01\n\x14StatefulSetCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x83\x01\n\x0fStatefulSetList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12.\n\x05items\x18\x02 \x03(\x0b\x32\x1f.k8s.io.api.apps.v1.StatefulSet\"Z\n/StatefulSetPersistentVolumeClaimRetentionPolicy\x12\x13\n\x0bwhenDeleted\x18\x01 \x01(\t\x12\x12\n\nwhenScaled\x18\x02 \x01(\t\"\x8d\x04\n\x0fStatefulSetSpec\x12\x10\n\x08replicas\x18\x01 \x01(\x05\x12\x45\n\x08selector\x18\x02 \x01(\x0b\x32\x33.k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x35\n\x08template\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.PodTemplateSpec\x12G\n\x14volumeClaimTemplates\x18\x04 \x03(\x0b\x32).k8s.io.api.core.v1.PersistentVolumeClaim\x12\x13\n\x0bserviceName\x18\x05 \x01(\t\x12\x1b\n\x13podManagementPolicy\x18\x06 \x01(\t\x12\x45\n\x0eupdateStrategy\x18\x07 \x01(\x0b\x32-.k8s.io.api.apps.v1.StatefulSetUpdateStrategy\x12\x1c\n\x14revisionHistoryLimit\x18\x08 \x01(\x05\x12\x17\n\x0fminReadySeconds\x18\t \x01(\x05\x12q\n$persistentVolumeClaimRetentionPolicy\x18\n \x01(\x0b\x32\x43.k8s.io.api.apps.v1.StatefulSetPersistentVolumeClaimRetentionPolicy\"\xac\x02\n\x11StatefulSetStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12\x10\n\x08replicas\x18\x02 \x01(\x05\x12\x15\n\rreadyReplicas\x18\x03 \x01(\x05\x12\x17\n\x0f\x63urrentReplicas\x18\x04 \x01(\x05\x12\x17\n\x0fupdatedReplicas\x18\x05 \x01(\x05\x12\x17\n\x0f\x63urrentRevision\x18\x06 \x01(\t\x12\x16\n\x0eupdateRevision\x18\x07 \x01(\t\x12\x16\n\x0e\x63ollisionCount\x18\t \x01(\x05\x12<\n\nconditions\x18\n \x03(\x0b\x32(.k8s.io.api.apps.v1.StatefulSetCondition\x12\x19\n\x11\x61vailableReplicas\x18\x0b \x01(\x05\"v\n\x19StatefulSetUpdateStrategy\x12\x0c\n\x04type\x18\x01 \x01(\t\x12K\n\rrollingUpdate\x18\x02 \x01(\x0b\x32\x34.k8s.io.api.apps.v1.RollingUpdateStatefulSetStrategyB\x14Z\x12k8s.io/api/apps/v1')



_CONTROLLERREVISION = DESCRIPTOR.message_types_by_name['ControllerRevision']
_CONTROLLERREVISIONLIST = DESCRIPTOR.message_types_by_name['ControllerRevisionList']
_DAEMONSET = DESCRIPTOR.message_types_by_name['DaemonSet']
_DAEMONSETCONDITION = DESCRIPTOR.message_types_by_name['DaemonSetCondition']
_DAEMONSETLIST = DESCRIPTOR.message_types_by_name['DaemonSetList']
_DAEMONSETSPEC = DESCRIPTOR.message_types_by_name['DaemonSetSpec']
_DAEMONSETSTATUS = DESCRIPTOR.message_types_by_name['DaemonSetStatus']
_DAEMONSETUPDATESTRATEGY = DESCRIPTOR.message_types_by_name['DaemonSetUpdateStrategy']
_DEPLOYMENT = DESCRIPTOR.message_types_by_name['Deployment']
_DEPLOYMENTCONDITION = DESCRIPTOR.message_types_by_name['DeploymentCondition']
_DEPLOYMENTLIST = DESCRIPTOR.message_types_by_name['DeploymentList']
_DEPLOYMENTSPEC = DESCRIPTOR.message_types_by_name['DeploymentSpec']
_DEPLOYMENTSTATUS = DESCRIPTOR.message_types_by_name['DeploymentStatus']
_DEPLOYMENTSTRATEGY = DESCRIPTOR.message_types_by_name['DeploymentStrategy']
_REPLICASET = DESCRIPTOR.message_types_by_name['ReplicaSet']
_REPLICASETCONDITION = DESCRIPTOR.message_types_by_name['ReplicaSetCondition']
_REPLICASETLIST = DESCRIPTOR.message_types_by_name['ReplicaSetList']
_REPLICASETSPEC = DESCRIPTOR.message_types_by_name['ReplicaSetSpec']
_REPLICASETSTATUS = DESCRIPTOR.message_types_by_name['ReplicaSetStatus']
_ROLLINGUPDATEDAEMONSET = DESCRIPTOR.message_types_by_name['RollingUpdateDaemonSet']
_ROLLINGUPDATEDEPLOYMENT = DESCRIPTOR.message_types_by_name['RollingUpdateDeployment']
_ROLLINGUPDATESTATEFULSETSTRATEGY = DESCRIPTOR.message_types_by_name['RollingUpdateStatefulSetStrategy']
_STATEFULSET = DESCRIPTOR.message_types_by_name['StatefulSet']
_STATEFULSETCONDITION = DESCRIPTOR.message_types_by_name['StatefulSetCondition']
_STATEFULSETLIST = DESCRIPTOR.message_types_by_name['StatefulSetList']
_STATEFULSETPERSISTENTVOLUMECLAIMRETENTIONPOLICY = DESCRIPTOR.message_types_by_name['StatefulSetPersistentVolumeClaimRetentionPolicy']
_STATEFULSETSPEC = DESCRIPTOR.message_types_by_name['StatefulSetSpec']
_STATEFULSETSTATUS = DESCRIPTOR.message_types_by_name['StatefulSetStatus']
_STATEFULSETUPDATESTRATEGY = DESCRIPTOR.message_types_by_name['StatefulSetUpdateStrategy']
ControllerRevision = _reflection.GeneratedProtocolMessageType('ControllerRevision', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLLERREVISION,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.ControllerRevision)
  })
_sym_db.RegisterMessage(ControllerRevision)

ControllerRevisionList = _reflection.GeneratedProtocolMessageType('ControllerRevisionList', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLLERREVISIONLIST,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.ControllerRevisionList)
  })
_sym_db.RegisterMessage(ControllerRevisionList)

DaemonSet = _reflection.GeneratedProtocolMessageType('DaemonSet', (_message.Message,), {
  'DESCRIPTOR' : _DAEMONSET,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DaemonSet)
  })
_sym_db.RegisterMessage(DaemonSet)

DaemonSetCondition = _reflection.GeneratedProtocolMessageType('DaemonSetCondition', (_message.Message,), {
  'DESCRIPTOR' : _DAEMONSETCONDITION,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DaemonSetCondition)
  })
_sym_db.RegisterMessage(DaemonSetCondition)

DaemonSetList = _reflection.GeneratedProtocolMessageType('DaemonSetList', (_message.Message,), {
  'DESCRIPTOR' : _DAEMONSETLIST,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DaemonSetList)
  })
_sym_db.RegisterMessage(DaemonSetList)

DaemonSetSpec = _reflection.GeneratedProtocolMessageType('DaemonSetSpec', (_message.Message,), {
  'DESCRIPTOR' : _DAEMONSETSPEC,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DaemonSetSpec)
  })
_sym_db.RegisterMessage(DaemonSetSpec)

DaemonSetStatus = _reflection.GeneratedProtocolMessageType('DaemonSetStatus', (_message.Message,), {
  'DESCRIPTOR' : _DAEMONSETSTATUS,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DaemonSetStatus)
  })
_sym_db.RegisterMessage(DaemonSetStatus)

DaemonSetUpdateStrategy = _reflection.GeneratedProtocolMessageType('DaemonSetUpdateStrategy', (_message.Message,), {
  'DESCRIPTOR' : _DAEMONSETUPDATESTRATEGY,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DaemonSetUpdateStrategy)
  })
_sym_db.RegisterMessage(DaemonSetUpdateStrategy)

Deployment = _reflection.GeneratedProtocolMessageType('Deployment', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMENT,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.Deployment)
  })
_sym_db.RegisterMessage(Deployment)

DeploymentCondition = _reflection.GeneratedProtocolMessageType('DeploymentCondition', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMENTCONDITION,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DeploymentCondition)
  })
_sym_db.RegisterMessage(DeploymentCondition)

DeploymentList = _reflection.GeneratedProtocolMessageType('DeploymentList', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMENTLIST,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DeploymentList)
  })
_sym_db.RegisterMessage(DeploymentList)

DeploymentSpec = _reflection.GeneratedProtocolMessageType('DeploymentSpec', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMENTSPEC,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DeploymentSpec)
  })
_sym_db.RegisterMessage(DeploymentSpec)

DeploymentStatus = _reflection.GeneratedProtocolMessageType('DeploymentStatus', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMENTSTATUS,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DeploymentStatus)
  })
_sym_db.RegisterMessage(DeploymentStatus)

DeploymentStrategy = _reflection.GeneratedProtocolMessageType('DeploymentStrategy', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMENTSTRATEGY,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.DeploymentStrategy)
  })
_sym_db.RegisterMessage(DeploymentStrategy)

ReplicaSet = _reflection.GeneratedProtocolMessageType('ReplicaSet', (_message.Message,), {
  'DESCRIPTOR' : _REPLICASET,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.ReplicaSet)
  })
_sym_db.RegisterMessage(ReplicaSet)

ReplicaSetCondition = _reflection.GeneratedProtocolMessageType('ReplicaSetCondition', (_message.Message,), {
  'DESCRIPTOR' : _REPLICASETCONDITION,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.ReplicaSetCondition)
  })
_sym_db.RegisterMessage(ReplicaSetCondition)

ReplicaSetList = _reflection.GeneratedProtocolMessageType('ReplicaSetList', (_message.Message,), {
  'DESCRIPTOR' : _REPLICASETLIST,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.ReplicaSetList)
  })
_sym_db.RegisterMessage(ReplicaSetList)

ReplicaSetSpec = _reflection.GeneratedProtocolMessageType('ReplicaSetSpec', (_message.Message,), {
  'DESCRIPTOR' : _REPLICASETSPEC,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.ReplicaSetSpec)
  })
_sym_db.RegisterMessage(ReplicaSetSpec)

ReplicaSetStatus = _reflection.GeneratedProtocolMessageType('ReplicaSetStatus', (_message.Message,), {
  'DESCRIPTOR' : _REPLICASETSTATUS,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.ReplicaSetStatus)
  })
_sym_db.RegisterMessage(ReplicaSetStatus)

RollingUpdateDaemonSet = _reflection.GeneratedProtocolMessageType('RollingUpdateDaemonSet', (_message.Message,), {
  'DESCRIPTOR' : _ROLLINGUPDATEDAEMONSET,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.RollingUpdateDaemonSet)
  })
_sym_db.RegisterMessage(RollingUpdateDaemonSet)

RollingUpdateDeployment = _reflection.GeneratedProtocolMessageType('RollingUpdateDeployment', (_message.Message,), {
  'DESCRIPTOR' : _ROLLINGUPDATEDEPLOYMENT,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.RollingUpdateDeployment)
  })
_sym_db.RegisterMessage(RollingUpdateDeployment)

RollingUpdateStatefulSetStrategy = _reflection.GeneratedProtocolMessageType('RollingUpdateStatefulSetStrategy', (_message.Message,), {
  'DESCRIPTOR' : _ROLLINGUPDATESTATEFULSETSTRATEGY,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.RollingUpdateStatefulSetStrategy)
  })
_sym_db.RegisterMessage(RollingUpdateStatefulSetStrategy)

StatefulSet = _reflection.GeneratedProtocolMessageType('StatefulSet', (_message.Message,), {
  'DESCRIPTOR' : _STATEFULSET,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.StatefulSet)
  })
_sym_db.RegisterMessage(StatefulSet)

StatefulSetCondition = _reflection.GeneratedProtocolMessageType('StatefulSetCondition', (_message.Message,), {
  'DESCRIPTOR' : _STATEFULSETCONDITION,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.StatefulSetCondition)
  })
_sym_db.RegisterMessage(StatefulSetCondition)

StatefulSetList = _reflection.GeneratedProtocolMessageType('StatefulSetList', (_message.Message,), {
  'DESCRIPTOR' : _STATEFULSETLIST,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.StatefulSetList)
  })
_sym_db.RegisterMessage(StatefulSetList)

StatefulSetPersistentVolumeClaimRetentionPolicy = _reflection.GeneratedProtocolMessageType('StatefulSetPersistentVolumeClaimRetentionPolicy', (_message.Message,), {
  'DESCRIPTOR' : _STATEFULSETPERSISTENTVOLUMECLAIMRETENTIONPOLICY,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.StatefulSetPersistentVolumeClaimRetentionPolicy)
  })
_sym_db.RegisterMessage(StatefulSetPersistentVolumeClaimRetentionPolicy)

StatefulSetSpec = _reflection.GeneratedProtocolMessageType('StatefulSetSpec', (_message.Message,), {
  'DESCRIPTOR' : _STATEFULSETSPEC,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.StatefulSetSpec)
  })
_sym_db.RegisterMessage(StatefulSetSpec)

StatefulSetStatus = _reflection.GeneratedProtocolMessageType('StatefulSetStatus', (_message.Message,), {
  'DESCRIPTOR' : _STATEFULSETSTATUS,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.StatefulSetStatus)
  })
_sym_db.RegisterMessage(StatefulSetStatus)

StatefulSetUpdateStrategy = _reflection.GeneratedProtocolMessageType('StatefulSetUpdateStrategy', (_message.Message,), {
  'DESCRIPTOR' : _STATEFULSETUPDATESTRATEGY,
  '__module__' : 'k8s.io.api.apps.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.apps.v1.StatefulSetUpdateStrategy)
  })
_sym_db.RegisterMessage(StatefulSetUpdateStrategy)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\022k8s.io/api/apps/v1'
  _CONTROLLERREVISION._serialized_start=307
  _CONTROLLERREVISION._serialized_end=474
  _CONTROLLERREVISIONLIST._serialized_start=477
  _CONTROLLERREVISIONLIST._serialized_end=622
  _DAEMONSET._serialized_start=625
  _DAEMONSET._serialized_end=806
  _DAEMONSETCONDITION._serialized_start=809
  _DAEMONSETCONDITION._serialized_end=964
  _DAEMONSETLIST._serialized_start=966
  _DAEMONSETLIST._serialized_end=1093
  _DAEMONSETSPEC._serialized_start=1096
  _DAEMONSETSPEC._serialized_end=1361
  _DAEMONSETSTATUS._serialized_start=1364
  _DAEMONSETSTATUS._serialized_end=1690
  _DAEMONSETUPDATESTRATEGY._serialized_start=1692
  _DAEMONSETUPDATESTRATEGY._serialized_end=1798
  _DEPLOYMENT._serialized_start=1801
  _DEPLOYMENT._serialized_end=1985
  _DEPLOYMENTCONDITION._serialized_start=1988
  _DEPLOYMENTCONDITION._serialized_end=2212
  _DEPLOYMENTLIST._serialized_start=2215
  _DEPLOYMENTLIST._serialized_end=2344
  _DEPLOYMENTSPEC._serialized_start=2347
  _DEPLOYMENTSPEC._serialized_end=2669
  _DEPLOYMENTSTATUS._serialized_start=2672
  _DEPLOYMENTSTATUS._serialized_end=2925
  _DEPLOYMENTSTRATEGY._serialized_start=2927
  _DEPLOYMENTSTRATEGY._serialized_end=3029
  _REPLICASET._serialized_start=3032
  _REPLICASET._serialized_end=3216
  _REPLICASETCONDITION._serialized_start=3219
  _REPLICASETCONDITION._serialized_end=3375
  _REPLICASETLIST._serialized_start=3378
  _REPLICASETLIST._serialized_end=3507
  _REPLICASETSPEC._serialized_start=3510
  _REPLICASETSPEC._serialized_end=3695
  _REPLICASETSTATUS._serialized_start=3698
  _REPLICASETSTATUS._serialized_end=3903
  _ROLLINGUPDATEDAEMONSET._serialized_start=3906
  _ROLLINGUPDATEDAEMONSET._serialized_end=4072
  _ROLLINGUPDATEDEPLOYMENT._serialized_start=4075
  _ROLLINGUPDATEDEPLOYMENT._serialized_end=4242
  _ROLLINGUPDATESTATEFULSETSTRATEGY._serialized_start=4244
  _ROLLINGUPDATESTATEFULSETSTRATEGY._serialized_end=4371
  _STATEFULSET._serialized_start=4374
  _STATEFULSET._serialized_end=4561
  _STATEFULSETCONDITION._serialized_start=4564
  _STATEFULSETCONDITION._serialized_end=4721
  _STATEFULSETLIST._serialized_start=4724
  _STATEFULSETLIST._serialized_end=4855
  _STATEFULSETPERSISTENTVOLUMECLAIMRETENTIONPOLICY._serialized_start=4857
  _STATEFULSETPERSISTENTVOLUMECLAIMRETENTIONPOLICY._serialized_end=4947
  _STATEFULSETSPEC._serialized_start=4950
  _STATEFULSETSPEC._serialized_end=5475
  _STATEFULSETSTATUS._serialized_start=5478
  _STATEFULSETSTATUS._serialized_end=5778
  _STATEFULSETUPDATESTRATEGY._serialized_start=5780
  _STATEFULSETUPDATESTRATEGY._serialized_end=5898
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.study.v1 import study_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2


class StudyServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListStudies = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.StudyService/ListStudies',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.ListStudyRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.ListStudyResponse.FromString,
                )
        self.CreateStudy = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.StudyService/CreateStudy',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.CreateStudyRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.CreateStudyResponse.FromString,
                )
        self.GetStudy = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.StudyService/GetStudy',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.GetStudyRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.GetStudyResponse.FromString,
                )
        self.UpdateStudy = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.StudyService/UpdateStudy',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.UpdateStudyRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.UpdateStudyResponse.FromString,
                )
        self.DeleteStudy = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.StudyService/DeleteStudy',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.DeleteStudyRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.DeleteStudyResponse.FromString,
                )
        self.CreateStudyProfile = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.StudyService/CreateStudyProfile',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.CreateStudyProfileRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.CreateStudyProfileResponse.FromString,
                )
        self.GetStudyProfile = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.StudyService/GetStudyProfile',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.GetStudyProfileRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.GetStudyProfileResponse.FromString,
                )
        self.AbortStudy = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.StudyService/AbortStudy',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.AbortStudyRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.AbortStudyResponse.FromString,
                )
        self.PauseStudy = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.StudyService/PauseStudy',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.PauseStudyRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.PauseStudyResponse.FromString,
                )
        self.ResumeStudy = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.StudyService/ResumeStudy',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.ResumeStudyRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.ResumeStudyResponse.FromString,
                )
        self.CompleteSearch = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.StudyService/CompleteSearch',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.CompleteSearchRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.CompleteSearchResponse.FromString,
                )


class StudyServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListStudies(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateStudy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStudy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateStudy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteStudy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateStudyProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStudyProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AbortStudy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseStudy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeStudy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CompleteSearch(self, request, context):
        """Force completion of the search.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StudyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListStudies': grpc.unary_unary_rpc_method_handler(
                    servicer.ListStudies,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.ListStudyRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.ListStudyResponse.SerializeToString,
            ),
            'CreateStudy': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateStudy,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.CreateStudyRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.CreateStudyResponse.SerializeToString,
            ),
            'GetStudy': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStudy,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.GetStudyRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.GetStudyResponse.SerializeToString,
            ),
            'UpdateStudy': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateStudy,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.UpdateStudyRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.UpdateStudyResponse.SerializeToString,
            ),
            'DeleteStudy': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteStudy,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.DeleteStudyRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.DeleteStudyResponse.SerializeToString,
            ),
            'CreateStudyProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateStudyProfile,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.CreateStudyProfileRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.CreateStudyProfileResponse.SerializeToString,
            ),
            'GetStudyProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStudyProfile,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.GetStudyProfileRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.GetStudyProfileResponse.SerializeToString,
            ),
            'AbortStudy': grpc.unary_unary_rpc_method_handler(
                    servicer.AbortStudy,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.AbortStudyRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.AbortStudyResponse.SerializeToString,
            ),
            'PauseStudy': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseStudy,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.PauseStudyRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.PauseStudyResponse.SerializeToString,
            ),
            'ResumeStudy': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumeStudy,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.ResumeStudyRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.ResumeStudyResponse.SerializeToString,
            ),
            'CompleteSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.CompleteSearch,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.CompleteSearchRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.CompleteSearchResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.study.v1.StudyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StudyService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListStudies(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.StudyService/ListStudies',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.ListStudyRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.ListStudyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateStudy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.StudyService/CreateStudy',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.CreateStudyRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.CreateStudyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetStudy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.StudyService/GetStudy',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.GetStudyRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.GetStudyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateStudy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.StudyService/UpdateStudy',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.UpdateStudyRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.UpdateStudyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteStudy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.StudyService/DeleteStudy',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.DeleteStudyRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.DeleteStudyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateStudyProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.StudyService/CreateStudyProfile',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.CreateStudyProfileRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.CreateStudyProfileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetStudyProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.StudyService/GetStudyProfile',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.GetStudyProfileRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.GetStudyProfileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AbortStudy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.StudyService/AbortStudy',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.AbortStudyRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.AbortStudyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseStudy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.StudyService/PauseStudy',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.PauseStudyRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.PauseStudyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumeStudy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.StudyService/ResumeStudy',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.ResumeStudyRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.ResumeStudyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CompleteSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.StudyService/CompleteSearch',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.CompleteSearchRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_study_dot_v1_dot_study__pb2.CompleteSearchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
